@@ -12,7 +12,7 @@ Usage::
     client: IoTDeviceAdvisorClient = boto3.client("iotdeviceadvisor")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -36,7 +36,7 @@ __all__ = ("IoTDeviceAdvisorClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -51,7 +51,7 @@ class Exceptions:
 
 class IoTDeviceAdvisorClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html)
     """
 
@@ -67,7 +67,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#can_paginate)
         """
 
@@ -75,12 +75,12 @@ class IoTDeviceAdvisorClient(BaseClient):
         self,
         *,
         suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> CreateSuiteDefinitionResponseTypeDef:
         """
         Creates a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#create_suite_definition)
         """
 
@@ -88,21 +88,21 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Deletes a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#delete_suite_definition)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#generate_presigned_url)
         """
 
@@ -112,7 +112,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Gets information about a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_definition)
         """
 
@@ -122,7 +122,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Gets information about a Device Advisor test suite run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_run)
         """
 
@@ -133,7 +133,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         Gets a report download link for a successful Device Advisor qualifying test
         suite run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#get_suite_run_report)
         """
 
@@ -143,7 +143,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Lists the Device Advisor test suites you have created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_suite_definitions)
         """
 
@@ -158,7 +158,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Lists the runs of the specified Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_suite_runs)
         """
 
@@ -166,7 +166,7 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Lists the tags attached to an IoT Device Advisor resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#list_tags_for_resource)
         """
 
@@ -176,12 +176,12 @@ class IoTDeviceAdvisorClient(BaseClient):
         suiteDefinitionId: str,
         suiteDefinitionVersion: str = None,
         suiteRunConfiguration: "SuiteRunConfigurationTypeDef" = None,
-        tags: Dict[str, str] = None
+        tags: Mapping[str, str] = None
     ) -> StartSuiteRunResponseTypeDef:
         """
         Starts a Device Advisor test suite run.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#start_suite_run)
         """
 
@@ -189,23 +189,23 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Stops a Device Advisor test suite run that is currently running.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.stop_suite_run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.stop_suite_run)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#stop_suite_run)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Adds to and modifies existing tags of an IoT Device Advisor resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes tags from an IoT Device Advisor resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#untag_resource)
         """
 
@@ -218,6 +218,6 @@ class IoTDeviceAdvisorClient(BaseClient):
         """
         Updates a Device Advisor test suite.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotdeviceadvisor/client.html#update_suite_definition)
         """
